@@ -41,7 +41,7 @@ except ImportError:
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '1.5'
+__version__ = '1.6'
 __website__ = 'https://github.com/stefankoegl/python-json-pointer'
 __license__ = 'Modified BSD License'
 
@@ -248,9 +248,12 @@ class JsonPointer(object):
             return doc[part]
 
     def contains(self, ptr):
-        """ Returns True if self contains the given ptr """
-        return len(self.parts) > len(ptr.parts) and \
-             self.parts[:len(ptr.parts)] == ptr.parts
+        """Returns True if self contains the given ptr"""
+        return self.parts[:len(ptr.parts)] == ptr.parts
+
+    def __contains__(self, item):
+        """Returns True if self contains the given ptr"""
+        return self.contains(item)
 
     @property
     def path(self):
